@@ -1,8 +1,8 @@
 ﻿import re
 from math import pi, pow
 
-from Core import Coordinate
-from Geo import LinearProjection, MercatorProjection, deriveTransformation
+from .Core import Coordinate
+from .Geo import LinearProjection, MercatorProjection, deriveTransformation
 
 ids = ('MICROSOFT_ROAD', 'MICROSOFT_AERIAL', 'MICROSOFT_HYBRID',
        'YAHOO_ROAD',     'YAHOO_AERIAL',     'YAHOO_HYBRID',
@@ -16,9 +16,6 @@ class IMapProvider:
     def getTileUrls(self, coordinate):
         raise NotImplementedError("Abstract method not implemented by subclass.")
 
-    def getTileUrls(self, coordinate):
-        raise NotImplementedError("Abstract method not implemented by subclass.")
-
     def tileWidth(self):
         raise NotImplementedError("Abstract method not implemented by subclass.")
     
@@ -31,9 +28,6 @@ class IMapProvider:
     def coordinateLocation(self, location):
         return self.projection.coordinateLocation(location)
 
-    def sourceCoordinate(self, coordinate):
-        raise NotImplementedError("Abstract method not implemented by subclass.")
-
     def sourceCoordinate(self, coordinate):
         wrappedColumn = coordinate.column % pow(2, coordinate.zoom)
         
