@@ -1,8 +1,9 @@
+from __future__ import print_function
 """
 >>> m = Map(Microsoft.RoadProvider(), Core.Point(600, 600), Core.Coordinate(3165, 1313, 13), Core.Point(-144, -94))
 >>> p = m.locationPoint(Geo.Location(37.804274, -122.262940))
 >>> p
-(370.724, 342.549)
+(370.752, 342.626)
 >>> m.pointLocation(p)
 (37.804, -122.263)
 
@@ -68,13 +69,21 @@ __version__ = open(os.path.join(os.path.dirname(__file__), 'VERSION')).read().st
 
 import sys
 import urllib
-import httplib
-import urlparse
-import StringIO
 import math
-import thread
 import time
 
+try:
+    import httplib
+    import urlparse
+    import StringIO
+    import thread
+except ImportError:
+    # Python 3
+    import http.client as httplib
+    import urllib.parse as urlparse
+    from io import StringIO
+    import _thread as thread
+
 try:
     import Image
 except ImportError:
@@ -85,11 +94,11 @@ except ImportError:
         # maybe that's not what you're using MMaps for?
         Image = None
 
-import Tiles
-import Providers
-import Core
-import Geo
-import Yahoo, Microsoft, BlueMarble, OpenStreetMap, CloudMade, MapQuest, Stamen
+from . import Tiles
+from . import Providers
+from . import Core
+from . import Geo
+from . import Yahoo, Microsoft, BlueMarble, OpenStreetMap, CloudMade, MapQuest, Stamen
 import time
 
 # a handy list of possible providers, which isn't
@@ -174,7 +183,7 @@ def calculateMapExtent(provider, width, height, *args):
         returns the coordinate of an initial tile and its point placement,
         relative to the map center.
     """
-    coordinates = map(provider.locationCoordinate, args)
+    coordinates = list(map(provider.locationCoordinate, args))
     
     TL = Core.Coordinate(min([c.row for c in coordinates]),
                          min([c.column for c in coordinates]),
@@ -221,7 +230,7 @@ def printlocked(lock, *stuff):
     """
     """
     if lock.acquire():
-        print ' '.join([str(thing) for thing in stuff])
+        print(' '.join([str(thing) for thing in stuff]), file=sys.stderr)
         lock.release()
 
 class TileRequest:
@@ -272,7 +281,7 @@ class TileRequest:
                         cache[(netloc, path, query)] = img
                         lock.release()
                 
-                elif scheme == 'http':
+                elif scheme in ('http', 'https'):
                     conn = httplib.HTTPConnection(netloc)
                     conn.request('GET', path + ('?' + query).rstrip('?'), headers={'User-Agent': 'Modest Maps python branch (http://modestmaps.com)'})
                     response = conn.getresponse()
